@@ -1,7 +1,7 @@
-makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = FALSE) {
+makefolds <- function(ina, nfolds = 10, stratified = TRUE, seed = NULL) {
   names <- paste("Fold", 1:nfolds)
   runs <- sapply(names, function(x) NULL)
-  if (seed)  set.seed(1234)
+  if ( !is.null(seed) )  set.seed(seed)
 
   if ( !stratified ) {
     oop <- options(warn = -1)
